#include <stdio.h>
#include "nist.h"

/* Variable declarations used in C functions: */
double pmpa;
double tdegk;

/* Temperature increment used to bias properties away from the saturation line
   to ensure that the correct phase is evaluated.  */
const double delt = 0.0001;

/* Function Declarations:  */
double Beta_Liq(double p, double t);
double Beta_Vap(double p, double t);
double Cp_Liq(double p, double t);
double Cp_Vap(double p, double t);
double Hfg_Sat(double p);
double H_Liq(double p, double t);
double H_Liq_Sat(double p);
double H_Vap(double p, double t);
double H_Vap_Sat(double p);
double K_Liq(double p, double t);
double K_Vap(double p, double t);
double P_Sat(double t);
double Pr_Liq(double p, double t);
double Pr_Liq_Sat(double p);
double Pr_Vap(double p, double t);
double Pr_Vap_Sat(double p);
double Rho_Liq(double p, double t);
double Rho_Liq_Sat(double p);
double Rho_Vap(double p, double t);
double Rho_Vap_Sat(double p);
double Sigma(double p);
double T_Sat(double p);
double Visc_Liq(double p, double t);
double Visc_Vap(double p, double t);

/* Function Declarations for interface to NIST routines:  */
double GETLIQPROP(double PMPA, double T, int IPROP);
double GETVAPPROP(double PMPA, double T, int IPROP);
double HF(double PMPA);
double HFG(double PMPA);
double HG(double PMPA);
double PR(double PMPA, double TDEGK, int IPROP);
double RHO(double PMPA, double TDEGK, int IPROP);
double SATP(double TDEGK);
double SATTEMP(double PMPA);
double SURFT(double PMPA);

int main(void)
{
   double res;
   double tliq;
   double tvap;

   pmpa = 0.2;

   double TF;
   TF = T_Sat(pmpa);

   tliq = 300.;
   tvap = 1000.;

   res = Rho_Liq(pmpa, TF);
   printf(" Rho Liquid Sat = %.6e\n", res);

   res = Rho_Liq(pmpa, tliq);
   printf("Rho Liquid = %.6e\n", res);

   res = Rho_Vap(pmpa, TF);
   printf("Rho Vapor Sat = %.6e\n", res);

   res = Rho_Vap(pmpa, tvap);
   printf("Rho Vapor = %.6e\n", res);

   res = K_Liq(pmpa, tliq);
   printf("Cond Liquid = %.6e\n", res);

   return 0;
}

/*
 *  Liquid thermal expansion coefficient (1/K) as fn. of pressure (MPa) &
 *  temperature (deg K).
 */
double Beta_Liq(double pmpa, double tdegk)
{
   const int iprop = 15;
   return GETLIQPROP(pmpa, tdegk, iprop);
}

/*
 *  Vapor thermal expansion coefficient (1/K) as fn. of pressure (MPa) &
 *  temperature (deg K).
 */
double Beta_Vap(double pmpa, double tdegk)
{
   const int iprop = 15;
   return GETVAPPROP(pmpa, tdegk, iprop);
}

/*
 *  Liquid specific heat (J/kg-K) as fn. of pressure (MPa) &
 *  temperature (deg K).
 */
double Cp_Liq(double pmpa, double tdegk)
{
   const int iprop = 9;
   return 1000. * GETLIQPROP(pmpa, tdegk, iprop);
}

/*
 *  Vapor specific heat (J/kg-K) as fn. of pressure (MPa) &
 *  temperature (deg K).
 */
double Cp_Vap(double pmpa, double tdegk)
{
   const int iprop = 9;
   return 1000. * GETVAPPROP(pmpa, tdegk, iprop);
}

/*
 *  Saturated Liquid enthalpy (J/kg) as fn. of pressure (MPa).
 */
double Hfg_Sat(double pmpa)
{
   return 1000. * HFG(pmpa);
}

/*
 *  Liquid enthalpy (J/kg) as fn. of pressure (MPa) &
 *  temperature (deg K).
 */
double H_Liq(double pmpa, double tdegk)
{
   const int iprop = 6;
   return 1000. * GETLIQPROP(pmpa, tdegk, iprop);
}

/*
 *  Saturated Liquid enthalpy (J/kg) as fn. of pressure (MPa).
 */
double H_Liq_Sat(double pmpa)
{
   return 1000. * HF(pmpa);
}

/*
 *  Vapor enthalpy (J/kg) as fn. of pressure (MPa) &
 *  temperature (deg K).
 */
double H_Vap(double pmpa, double tdegk)
{
   const int iprop = 6;
   return 1000. * GETVAPPROP(pmpa, tdegk, iprop);
}

/*
 *  Saturated Vapor enthalpy (J/kg) as fn. of pressure (MPa).
 */
double H_Vap_Sat(double pmpa)
{
   return 1000. * HG(pmpa);
}

/*
 *  Liquid thermal conductivity (W/m-K) as fn. of pressure (MPa) &
 *  temperature (deg K).
 */
double K_Liq(double pmpa, double tdegk)
{
   const int iprop = 20;
   return GETLIQPROP(pmpa, tdegk, iprop);
}

/*
 *  Vapor thermal conductivity (W/m-K) as fn. of pressure (MPa) &
 *  temperature (deg K).
 */
double K_Vap(double pmpa, double tdegk)
{
   const int iprop = 20;
   return GETVAPPROP(pmpa, tdegk, iprop);
}

/*
 *  Saturation pressure (MPa) as fn. of temperature (deg K).
 */
double P_Sat(double tdegk)
{
   return SATP(tdegk);
}

/*
 *  Liquid Prandtl No. as fn. of pressure (MPa) & temperature (deg K).
 */
double Pr_Liq(double pmpa, double tdegk)
{
   const int iprop = 1;
   return PR(pmpa, tdegk, iprop);
}

/*
 *  Saturated Liquid Prandtl No. as fn. of pressure (MPa).
 */
double Pr_Liq_Sat(double pmpa)
{
   const int iprop = 2;
   return PR(pmpa, tdegk, iprop);
}

/*
 *  Vapor Prandtl No. as fn. of pressure (MPa) & temperature (deg K).
 */
double Pr_Vap(double pmpa, double tdegk)
{
   const int iprop = 4;
   return PR(pmpa, tdegk, iprop);
}

/*
 *  Saturated vapor Prandtl No. as fn. of pressure (MPa).
 */
double Pr_Vap_Sat(double pmpa)
{
   const int iprop = 3;
   return PR(pmpa, tdegk, iprop);
}

/*
 *  Liquid denisty (kg/m3) as fn. of pressure (MPa) & temperature (deg K).
 */
double Rho_Liq(double pmpa, double tdegk)
{
   const int iprop = 1;
   return RHO(pmpa, tdegk, iprop);
}

/*
 *  Saturated Liquid denisty (kg/m3) as fn. of pressure (MPa).
 */
double Rho_Liq_Sat(double pmpa)
{
   const int iprop = 2;
   return RHO(pmpa, tdegk, iprop);
}

/*
 *  Vapor denisty (kg/m3) as fn. of pressure (MPa) & temperature (deg K).
 */
double Rho_Vap(double pmpa, double tdegk)
{
   const int iprop = 4;
   return RHO(pmpa, tdegk, iprop);
}

/*
 *  Saturated vapor denisty (kg/m3) as fn. of pressure (MPa).
 */
double Rho_Vap_Sat(double pmpa)
{
   const int iprop = 3;
   return RHO(pmpa, tdegk, iprop);
}

/*
 *  Surface tension (N/m) as fn. of pressure (MPa).
 */
double Sigma(double pmpa)
{
   return SURFT(pmpa);
}

/*
 *  Saturation temperature (deg K) as fn. of pressure (MPa).
 */
double T_Sat(double pmpa)
{
   return SATTEMP(pmpa);
}

/*
 *  Liquid viscosity (N-s/m2) as fn. of pressure (MPa) &
 *  temperature (deg K).
 */
double Visc_Liq(double pmpa, double tdegk)
{
   const int iprop = 21;
   return GETLIQPROP(pmpa, tdegk, iprop);
}

/*
 *  Vapor viscosity (N-s/m2) as fn. of pressure (MPa) &
 *  temperature (deg K).
 */
double Visc_Vap(double pmpa, double tdegk)
{
   const int iprop = 21;
   return GETVAPPROP(pmpa, tdegk, iprop);
}
