#include <math.h>
#include "nist.h"
#include "proppk.h"
#include "solvpk.h"


/*
	Function declarations from AUXPK that are used in this file:
*/
void PVAP(double TR, double *PS, double *DPSDT);
double DLSAT(double TR);
double DVSAT(double TR);
double TVAP(double PR);
double DLSATC(double TR);
double DVSATC(double TR);


/*
	Function declarations used in this file:
*/
int DFIND1(double *DOUT, double P, double D, double TR, double *DPD, int IWANT[], double PROPR[]);
int DFIND2(double *DOUT, double P, double D, double TR, double *DPD, int IWANT[], double PROPR[]);


int DFIND(double *DOUT, double P, double D, double TR, double *DPD, int IWANT[], double PROPR[])
{
/*
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                     *** DFIND ***                                    C
C THIS ROUTINE FINDS THE REDUCED DENSITY CORRESPONDING TO A GIVEN      C
C REDUCED TEMPERATURE TR AND REDUCED (P/PC) PRESSURE P.  AN            C
C INITIAL GUESS (D) IS REQUIRED, AND THE VALUE OF DPDD IS ALSO         C
C RETURNED.  ROUTINE ADAPTED DIRECTLY FROM OLD (1984) STEAM PROGRAM.   C
C                                                                      C
C ARGUMENT LIST:                                                       C
C  NAME  TYPE I/O? EXPLANATION                                         C
C ------ ---- ---- --------------------------------------------------  C
C DOUT    R    O   REDUCED DENSITY RHO/RHOC AT TAU AND P               C
C P       R    I   REDUCED (P/PC) PRESSURE                             C
C D       R    I   INITIAL GUESS FOR REDUCED DENSITY, RHO/RHOC         C
C TR      R    I   REDUCED TEMPERATURE, T/TC                           C
C DPD     R    O   FIRST DERIVATIVE OF P WITH RESPECT TO D AT DOUT     C
C IWANT   IA   -   PROPERTY REQUEST VECTOR FOR USE IN PROPS2 ROUTINE   C
C PROPR   RA   O   VECTOR OF REDUCED PROPERTIES AS REQUESTED BY IWANT  C
C                  TO BE RETURNED BY THE PROP2 ROUTINE                 C
C                  RELEVANT PROPERTIES HERE ARE:                       C
C                  2: REDUCED PRESSURE P/(RHO*R*T)                     C
C                 12: REDUCED DP/DRHO DPDR/RT                          C
C IERR    I    O   RETURN STATUS FLAG.  NEGATIVES ARE FROM DFIND1,     C
C                  POSITIVES FROM DFIND2.  MEANINGS:                   C
C                  0: CONVERGED                                        C
C                 -2: UNABLE TO BOUND ROOT (DFIND1)                    C
C                 -3: UNABLE TO CONVERGE BOUNDED ROOT (DFIND1)         C
C                  1: NO ROOT FOR REQUESTED PHASE.  RETURNS D WHERE    C
C                     DPD = 0 (DFIND2)                                 C
C                  2: UNABLE TO BOUND ROOT (DFIND2)                    C
C                  3: UNABLE TO CONVERGE BOUNDED ROOT (DFIND2)         C
C                                                                      C
C MAINTENANCE:                                                         C
C                                                                      C
C 12JUL95 - ADAPTED FROM OLD STEAM PROGRAM BY AHH                      C
C 20JUL95 - AHH: IWANT AND PROPR DIMENSIONED TO 19                     C
C 21AUG95 - AHH: CHANGE TO CALL DFIND1 FOR SUPERCRITICAL TEMPERATURES  C
C 28AUG95 - AHH: CHANGE TO CALL DFIND2 FOR SUBCRITICAL TEMPERATURES    C
C 30AUG95 - AHH: ADD IERR FLAG TO RETURN STATUS                        C
C 06SEP95 - AHH: USE TR INSTEAD OF TAU IN ARGUMENT LIST                C
C 28SEP95 - AHH: PARAMETERIZE NUMBER OF PROPERTIES                     C
C 30AUG96 - AHH: LOWERCASE INCLUDES FOR OTHER PLATFORMS                C
C                                                                      C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
*/
	int IERR;
	
    if (TR >= 1.0) 
        IERR = DFIND1(DOUT, P, D, TR, DPD, IWANT, PROPR);
    else
        IERR = DFIND2(DOUT, P, D, TR, DPD, IWANT, PROPR);
      
    return IERR;
}

int DFIND0(double *DOUT, double PR, double TR, double *DPD, int IWANT[], double PROPR[])
{
/*
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                     *** DFIND0 ***                                   C
C THIS ROUTINE FINDS THE REDUCED DENSITY CORRESPONDING TO A GIVEN      C
C REDUCED TEMPERATURE TR AND REDUCED (P/PC) PRESSURE PR.  IN           C
C CONTRAST TO DFIND, NO INITIAL GUESS IS REQUIRED (ONE IS GENERATED    C
C INTERNALLY).  THE VALUE OF DPD IS ALSO RETURNED.                     C
C                                                                      C
C ARGUMENT LIST:                                                       C
C  NAME  TYPE I/O? EXPLANATION                                         C
C ------ ---- ---- --------------------------------------------------  C
C DOUT    R    O   REDUCED DENSITY RHO/RHOC AT TAU AND PR              C
C PR      R    I   REDUCED (P/PC) PRESSURE                             C
C TR      R    I   REDUCED TEMPERATURE, T/TC                           C
C DPD     R    O   FIRST DERIVATIVE OF PR WITH RESPECT TO D AT DOUT    C
C IWANT   IA   -   PROPERTY REQUEST VECTOR FOR USE IN PROPS2 ROUTINE   C
C PROPR   RA   O   VECTOR OF REDUCED PROPERTIES AS REQUESTED BY IWANT  C
C                  TO BE RETURNED BY THE PROP2 ROUTINE                 C
C                  RELEVANT PROPERTIES HERE ARE:                       C
C                  2: REDUCED PRESSURE P/(RHO*R*T)                     C
C                 12: REDUCED DP/DRHO DPDR/RT                          C
C IERR    I    O   RETURN STATUS FLAG.  NEGATIVES ARE FROM DFIND1,     C
C                  POSITIVES FROM DFIND2.  MEANINGS:                   C
C                  0: CONVERGED                                        C
C                 -2: UNABLE TO BOUND ROOT (DFIND1)                    C
C                 -3: UNABLE TO CONVERGE BOUNDED ROOT (DFIND1)         C
C                  1: NO ROOT FOR REQUESTED PHASE.  RETURNS D WHERE    C
C                     DPD = 0 (DFIND2)                                 C
C                  2: UNABLE TO BOUND ROOT (DFIND2)                    C
C                  3: UNABLE TO CONVERGE BOUNDED ROOT (DFIND2)         C
C                                                                      C
C MAINTENANCE:                                                         C
C                                                                      C
C 30AUG95 - INITIAL CREATION FROM DFIND BY AHH                         C
C 06SEP95 - AHH: USE TR INSTEAD OF TAU IN ARGUMENT LIST                C
C 13SEP95 - AHH: FOR SUBCRITICAL, CALL PCOEX TO GET EXACT V-L BORDER   C
C 28SEP95 - AHH: PARAMETERIZE NUMBER OF PROPERTIES                     C
C 02OCT95 - AHH: IF T TOO LOW FOR PCOEX, USE AUXILIARY EQN. INSTEAD    C
C 03OCT95 - AHH: SPEED - GET INITIAL GUESSES FROM AUXILIARY EQUATIONS  C
C                UNLESS WITHIN 5% OF COEXISTENCE.  ALSO IMPROVE INIT.  C
C                GUESS FOR DENSE SUBCRITICAL VAPORS                    C
C 30AUG96 - AHH: LOWERCASE INCLUDES FOR OTHER PLATFORMS                C
C 04JUN97 - AHH: ALLOW EXTRAPOLATED LIQUIDS BELOW TRIPLE POINT         C
C                                                                      C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
*/
	int IERR;
	double PBOTR, P0AUX, DP0, P0, RHOL, RHOV, RGUESS; 
	
    PBOTR = PSMIN / PCW;
/* 
C IF TR >= 1, USE IDEAL GAS FOR INITIAL GUESS.  ALSO USE IDEAL GAS IF
C IN SUBCOOLED VAPOR REGION.  IF IN COMPRESSED LIQUID REGION, USE
C SATURATED LIQUID DENSITY AS INITIAL GUESS
C IF P BELOW MINIMUM FOR COEXISTENCE CALC, USE VAPOR INITIAL GUESS
*/
    if (TR < 1.0) 
    {
    	PVAP(TR, &P0AUX, &DP0);
    
        if (fabs(1.0 - P0AUX/PR) < 0.05) 
        {
          	IERR = PCOEX(TR, &P0, &RHOL, &RHOV, IWANT, PROPR);
          
          	if (IERR == 1) 
          	{
            	P0 = P0AUX;
            	RHOL = DLSAT(TR);
            	
            	if (PR > 0.1) 
            		RHOV = DVSAT(TR);
          	}
        }
        else       
        {
          	P0 = P0AUX;
          	RHOL = DLSAT(TR);
          	
          	if (PR > 0.1) 
          		RHOV = DVSAT(TR);
        }
        
        if ((PR < P0) || (PR < PBOTR)) 
        {
          	RGUESS = PR*PCW*1.0e3 / (RW*TR*TCW);
          	RGUESS = RGUESS / RHOCW;
          	
          	if (PR > 0.1) 
          		RGUESS = RGUESS + (PR/P0)*(RHOV-RGUESS);
        }
        else
          	RGUESS = RHOL;
    }
    else
    {
        RGUESS = PR*PCW*1.0e3 / (RW*TR*TCW);
        RGUESS = RGUESS / RHOCW;
    }
    
    IERR = DFIND(DOUT, PR, RGUESS, TR, DPD, IWANT, PROPR);
      
    return IERR;
}


int DFIND1(double *DOUT, double P, double D, double TR, double *DPD, int IWANT[], double PROPR[])
{
/*
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                     *** DFIND1 ***                                   C
C THIS ROUTINE FINDS THE REDUCED DENSITY CORRESPONDING TO A GIVEN      C
C REDUCED TEMPERATURE TR AND REDUCED (P/PC) PRESSURE P.  AN            C
C INITIAL GUESS (D) IS REQUIRED, AND THE VALUE OF DPDD IS ALSO         C
C RETURNED.  THIS ROUTINE IS SPECIFICALLY FOR A PURE FLUID AT TR > 1   C
C                                                                      C
C ARGUMENT LIST:                                                       C
C  NAME  TYPE I/O? EXPLANATION                                         C
C ------ ---- ---- --------------------------------------------------  C
C DOUT    R    O   REDUCED DENSITY RHO/RHOC AT TR AND P                C
C P       R    I   REDUCED (P/PC) PRESSURE                             C
C D       R    I   INITIAL GUESS FOR REDUCED DENSITY, RHO/RHOC         C
C TR      R    I   REDUCED TEMPERATURE, T/TC                           C
C DPD     R    O   FIRST DERIVATIVE OF P WITH RESPECT TO D AT DOUT     C
C IWANT   IA   -   PROPERTY REQUEST VECTOR FOR USE IN PROPS2 ROUTINE   C
C PROPR   RA   O   VECTOR OF REDUCED PROPERTIES AS REQUESTED BY IWANT  C
C                  TO BE RETURNED BY THE PROP2 ROUTINE                 C
C IERR    I    O   RETURN STATUS CODE                                  C
C                  0: CONVERGED                                        C
C                 -2: UNABLE TO BOUND ROOT                             C
C                 -3: UNABLE TO CONVERGE BOUNDED ROOT                  C
C                                                                      C
C MAINTENANCE:                                                         C
C                                                                      C
C 21AUG95 - INITIAL CREATION BY AHH                                    C
C 22AUG95 - AHH: SPEED UP BOUNDARY-FINDING A LITTLE                    C
C 30AUG95 - AHH: ADD IERR FLAG TO RETURN STATUS                        C
C 19SEP95 - AHH: FORCE AT LEAST A 1% STEP IN BOUNDED SECANT SEARCH     C
C 19SEP95 - AHH: SET DOLD AND POLD FOR CASE JUST ABOVE TC              C
C 28SEP95 - AHH: PARAMETERIZE NUMBER OF PROPERTIES                     C
C 30AUG96 - AHH: LOWERCASE INCLUDES FOR OTHER PLATFORMS                C
C                                                                      C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
*/
    static const double TCLOSE = 1.1;
    static const double TOL = 1.0e-8;

	int IERR;
	double DD, PNEW, DOLD, ERROLD, STEP, DPNEW, ERRNEW, DNEW, FLOW, FHIGH, FRDIST;
	double POLD, PHIGH, DHIGH, PLOW, DLOW, FNEW;
	
/*
C FIRST, EVALUATE P AND DP AT INITIAL GUESS (IF GUESS IS OK)
*/
    DD = D;
    
    if (DD <= 1.0e-8) 
    	DD = 1.0e-8;
      
    if (DD > 5.5) 
    	DD = 5.5;         
      
    PDP(DD, TR, &PNEW, DPD, IWANT, PROPR);
/*
C IF NOT TOO CLOSE TO TC, DO NEWTON ITERATION
*/
    if (TR > TCLOSE) 
    {
        DOLD = DD;
        ERROLD = PNEW - P;
   
STNO_10:
   		STEP = -ERROLD / *DPD;
   
        if (fabs(STEP) > 0.5*DOLD) 
          	STEP = copysign(0.5*DOLD, STEP);
        
        DNEW = DOLD + STEP;
        
STNO_20:   
		PDP(DNEW, TR, &PNEW, &DPNEW, IWANT, PROPR);
/*
C CHECK FOR CONVERGENCE
*/
        if (fabs(1.0 - PNEW/P) < TOL) 
        	goto STNO_999;
/*
C IF NOT CONVERGED, SEE IF ERROR HAS DECREASED.  IF NOT, CUT STEP IN HALF
C IF IT HAS, TAKE THE NEXT NEWTON STEP
*/
        ERRNEW = PNEW - P;
        
        if (fabs(ERRNEW) > fabs(ERROLD)) 
        {
          DNEW = 0.5*(DNEW + DOLD);
          goto STNO_20;
        }
        
        ERROLD = ERRNEW;
        DOLD = DNEW;
        *DPD = DPNEW;
        goto STNO_10;
    }
    else
    {
/*
C IF CLOSE TO TC, WORK BY BOUNDING THE SOLUTION
*/
        if (PNEW > P) 
        {
/*
C IF P TOO HIGH, GO DOWN IN DENSITY UNTIL SOLUTION BOUNDED
*/
          	DOLD = DD;
          	POLD = PNEW;
          
          	for (int i=1; i<=9; i++)
          	{
            	DNEW = (10-i)*0.1*DD;
            	PDP(DNEW, TR, &PNEW, &DPNEW, IWANT, PROPR);
            	
            	if (PNEW <= P) 
            	{
              		PHIGH = POLD;
              		DHIGH = DOLD;
              		PLOW = PNEW;
              		DLOW = DNEW;
              		goto STNO_222;
            	}
            	
            	DOLD = DNEW;
            	POLD = PNEW;
  			}
/*
C IF YOU GET HERE, TRY SUCCESSIVE HALVING OF THE DENSITY
*/
          	for (int i=1; i<=20; i++)
          	{
            	DNEW = 0.5*DOLD;
            	PDP(DNEW, TR, &PNEW, &DPNEW, IWANT, PROPR);
            	
            	if (PNEW <= P) 
            	{
              		PHIGH = POLD;
              		DHIGH = DOLD;
              		PLOW = PNEW;
              		DLOW = DNEW;
              		goto STNO_222;
            	}
            	
            	DOLD = DNEW;
            	POLD = PNEW;
 			}
/*
C IF YOU STILL HAVEN'T BRACKETED IT, GIVE UP
*/
          	IERR = -2;
          	*DOUT = DNEW;
          	*DPD = DPNEW;
          	return IERR;
		}
        else
        {
/*
C IF P TOO LOW, GO UP IN DENSITY UNTIL SOLUTION BOUNDED
*/
          	DOLD = DD;
          	POLD = PNEW;
          
          	for (int i=1; i<=100; i++)
          	{
            	DNEW = (10 + i)*0.1*DD;
            	PDP(DNEW, TR, &PNEW, &DPNEW, IWANT, PROPR);
            
            	if (PNEW >= P) 
            	{
              		PLOW = POLD;
              		DLOW = DOLD;
              		PHIGH = PNEW;
              		DHIGH = DNEW;
              		goto STNO_222;
            	}
            
            	DOLD = DNEW;
            	POLD = PNEW;
  			}
/*
C IF YOU STILL HAVEN'T BRACKETED IT, GIVE UP
*/
        	IERR = -2;
          	*DOUT = DNEW;
          	*DPD = DPNEW;
          	return IERR;
    	}
        
STNO_222:   
/*
C SOLUTION IS NOW BRACKETED, USE BOUNDED SECANT TO SOLVE
*/
    	FLOW = PLOW - P;
        FHIGH = PHIGH - P;
        
        for (int i=1; i<=100; i++)
        {
          	FRDIST = -FLOW / (FHIGH-FLOW);
          
          	if (FRDIST < 0.01) 
          		FRDIST = 0.01;
          
          	if (FRDIST > 0.99) 
          		FRDIST = 0.99;
          
          	DNEW = DLOW + FRDIST*(DHIGH - DLOW);
          	PDP(DNEW, TR, &PNEW, &DPNEW, IWANT, PROPR);
/*
C CHECK FOR CONVERGENCE
*/
          	if (fabs(1.0 - PNEW/P) < TOL) 
          		goto STNO_999;
/*
C MAKE NEW BOUNDS DEPENDING ON WHETHER NEW GUESS WAS HIGH OR LOW
*/
          	FNEW = PNEW - P;
          
          	if (FNEW >= 0.0) 
          	{
            	FHIGH = FNEW;
            	DHIGH = DNEW;
          	}
          	else
          	{
            	FLOW = FNEW;
            	DLOW = DNEW;
          	}
  		}
/*
C FAILURE TO CONVERGE
*/
        IERR = -3;
        *DOUT = DNEW;
        *DPD = DPNEW;
        return IERR;
    }

STNO_999: 
/*
C CONVERGENCE
*/
    IERR = 0;
    *DOUT = DNEW;
    *DPD = DPNEW;
    return IERR;       
}


int DFIND2(double *DOUT, double P, double D, double TR, double *DPD, int IWANT[], double PROPR[])
{
/*
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                     *** DFIND2 ***                                   C
C THIS ROUTINE FINDS THE REDUCED DENSITY CORRESPONDING TO A GIVEN      C
C REDUCED TEMPERATURE TR AND REDUCED (P/PC) PRESSURE P.  AN            C
C INITIAL GUESS (D) IS REQUIRED, AND THE VALUE OF DPDD IS ALSO         C
C RETURNED.  THIS ROUTINE IS SPECIFICALLY FOR A PURE FLUID AT TR < 1   C
C                                                                      C
C ARGUMENT LIST:                                                       C
C  NAME  TYPE I/O? EXPLANATION                                         C
C ------ ---- ---- --------------------------------------------------  C
C DOUT    R    O   REDUCED DENSITY RHO/RHOC AT TR AND P                C
C P       R    I   REDUCED (P/PC) PRESSURE                             C
C D       R    I   INITIAL GUESS FOR REDUCED DENSITY, RHO/RHOC         C
C TR      R    I   REDUCED TEMPERATURE, T/TC                           C
C DPD     R    O   FIRST DERIVATIVE OF P WITH RESPECT TO D AT DOUT     C
C IWANT   IA   -   PROPERTY REQUEST VECTOR FOR USE IN PROPS2 ROUTINE   C
C PROPR   RA   O   VECTOR OF REDUCED PROPERTIES AS REQUESTED BY IWANT  C
C                  TO BE RETURNED BY THE PROP2 ROUTINE                 C
C IERR    I    O   RETURN STATUS FLAG:                                 C
C                  0: SUCCESSFUL CONVERGENCE                           C
C                  1: NO ROOT FOR REQUESTED PHASE.  RETURNS D WHERE    C
C                     DPD = 0                                          C
C                  2: UNABLE TO BOUND ROOT                             C
C                  3: UNABLE TO CONVERGE BOUNDED ROOT                  C
C                                                                      C
C MAINTENANCE:                                                         C
C                                                                      C
C 22AUG95 - INITIAL CREATION BY AHH                                    C
C 30AUG95 - AHH: ADD IERR FLAG, HANDLE CASE WHERE REQUESTED V OR L     C
C                ROOT DOES NOT EXIST                                   C
C 31AUG95 - TIGHTEN CONVERGENCE TOLERANCE WHEN NEAR TC                 C
C 01SEP95 - FORCE AT LEAST A 1% STEP IN BOUNDED SECANT SEARCH          C
C 06SEP95 - AHH: BOUND INCREASE WHEN LOOKING FOR VAPOR ROOT            C
C 07SEP95 - AHH: FIX SEARCH FOR POSITIVE DP FOR VAPOR ROOTS            C
C 28SEP95 - AHH: PARAMETERIZE NUMBER OF PROPERTIES                     C
C 04OCT95 - AHH: IMPROVE FOR LOW DENSITIES                             C
C 19OCT95 - AHH: IMPROVE CONVERGENCE ONCE BOUNDED                      C
C 30AUG96 - AHH: LOWERCASE INCLUDES FOR OTHER PLATFORMS                C
C 09JUN97 - AHH: LOOSEN TOLERANCE FOR VERY LOW TEMPERATURES            C
C                                                                      C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
*/
	int IERR;
	double TOL, DD, PNEW, DPNEW, DOLD, POLD, DPOLD, FOLD, FNEW, DNEW;
	double FLOW, DLOW, DPLOW, FHIGH, DHIGH, DPHIGH, PSAV, DSAV, DPSAV;
	double PHIGH, FRDIST, PLOW, DINCR, DBOUND, TOL2;
	
    TOL = 1.0e-8;
    
    if (TR < 0.70) 
    	TOL = 1.0e-7;
    
    if (TR < 0.422) 
    	TOL = 1.0e-6;
/*
C FIRST, EVALUATE P AND DP AT INITIAL GUESS (IF GUESS IS OK)
*/
    DD = D;
      
    if (DD < 1.0e-20) 
    	DD = 1.0e-20;
      
    if (DD > 5.5) 
    	DD = 5.5;         
      
    PDP(DD, TR, &PNEW, &DPNEW, IWANT, PROPR);
/*
C FROM INITIAL GUESS, IDENTIFY WHETHER A VAPOR OR LIQUID ROOT IS WANTED
*/
    if (DD > 1.0) 
    {
/*
C LIQUID ROOT DESIRED.  IF YOU HAVE FOUND DP > 0, SEARCH TO FIND ROOT
C IF DP < 0, MUST GO UP UNTIL A POSITIVE DP IS FOUND
C AT THAT POINT, TREAT LIKE "NORMAL" CASE AND GO TO SEARCH FOR BOUND
*/        
    	if (DPNEW < 0.0) 
    	{
          	DOLD = DD;
          
          	for (int i=1; i<=100; i++)
          	{
            	DNEW = DOLD*1.05;
            	PDP(DNEW, TR, &PNEW, &DPNEW, IWANT, PROPR);
            	DOLD = DNEW;
            	DPOLD = DPNEW;
            
            	if (DPNEW > 0.0) 
            		goto STNO_99;
   			}
        }

        DOLD = DD;
        POLD = PNEW;
        DPOLD = DPNEW;
/*
C IF P TOO HIGH, GO DOWN IN DENSITY UNTIL SOLUTION BOUNDED
*/
STNO_99:
        if (PNEW > P) 
        {
          	for (int i=1; i<=100; i++)
          	{
            	DNEW = DOLD - 0.1*(DOLD - 1.0);
            	PDP(DNEW, TR, &PNEW, &DPNEW, IWANT, PROPR);
            	
            	if (DPNEW < 0.0) 
            	{
/*
C IF NEGATIVE DPD ENCOUNTERED, SEARCH FOR PLACE WHERE DPD=0.  IF P THERE
C IS STILL TOO HIGH, THEN THERE IS NO LIQUID ROOT.  BUT IF YOU GET A 
C POINT WITH DPD>0 AND P TOO LOW, THE ROOT IS BOUNDED AND YOU CAN SEARCH.
*/
              		FLOW = DPNEW;
              		FHIGH = DPOLD;
              		DLOW = DNEW;
              		DHIGH = DOLD;
              		DPLOW = DPNEW;
              		DPHIGH = DPOLD;
              		PSAV = POLD;
              		DSAV = DOLD;
              		DPSAV = DPOLD;
              
              		for (int j=1; j<=100; j++)
              		{
                		FRDIST = -FLOW / (FHIGH-FLOW);
               		 	DNEW = DLOW + FRDIST*(DHIGH-DLOW);
                		PDP(DNEW, TR, &PNEW, &DPNEW, IWANT, PROPR);
/*
C CHECK FOR BOUNDING OF DENSITY ROOT
*/
                		if ((DPNEW > 0.0) && (PNEW <= P)) 
                		{
                  			PHIGH = PSAV;
                  			DHIGH = DSAV;
                  			DPHIGH = DPSAV;
                  			PLOW = PNEW;
                  			DLOW = DNEW;
                  			DPLOW = DPNEW;
                  			goto STNO_444;
                		}
/*
C CHECK FOR CONVERGENCE ON DP=0
*/
                		if (fabs(DPNEW) < TOL) 
                		{
                  			*DOUT = DNEW;
                  			*DPD = DPNEW;
                  			IERR = 1;
                  			return IERR;
                		}
/*
C MAKE NEW BOUNDS DEPENDING ON WHETHER NEW GUESS WAS HIGH OR LOW
*/
                		FNEW = DPNEW;
                
                		if (FNEW >= 0.0) 
                		{
                  			FHIGH = FNEW;
                  			DHIGH = DNEW;
                  			DPHIGH = DPNEW;
                		}
                		else
                		{
                  			FLOW = FNEW;
                  			DLOW = DNEW;
                  			DPLOW = DPNEW;
                		}
  					}
				}
            
            	if (PNEW <= P) 
            	{
              		PHIGH = POLD;
              		DHIGH = DOLD;
              		DPHIGH = DPOLD;
              		PLOW = PNEW;
              		DLOW = DNEW;
              		DPLOW = DPNEW;
              		goto STNO_444;
            	}
            
            	DOLD = DNEW;
            	POLD = PNEW;
            	DPOLD = DPNEW;
  			}
/*
C IF YOU STILL HAVEN'T BRACKETED IT, GIVE UP
*/
          *DOUT = DNEW;
          *DPD = DPNEW;
          IERR = 2;
          return IERR;
        }
        else
        {
/*
C IF P TOO LOW, GO UP IN DENSITY UNTIL SOLUTION BOUNDED
*/
          	for (int i=1; i<=100; i++)
          	{
            	DNEW = DOLD*1.1;
            	PDP(DNEW, TR, &PNEW, &DPNEW, IWANT, PROPR);
            	
            	if (PNEW >= P) 
            	{
              		PLOW = POLD;
              		DLOW = DOLD;
              		DPLOW = DPOLD;
              		PHIGH = PNEW;
              		DHIGH = DNEW;
              		DPHIGH = DPNEW;
              		goto STNO_444;
            	}
            	
            	DOLD = DNEW;
            	POLD = PNEW;
            	DPOLD = DPNEW;
  			}
/*
C IF YOU STILL HAVEN'T BRACKETED IT, GIVE UP
*/
          	*DOUT = DNEW;
          	*DPD = DPNEW;
          	IERR = 2;
          	return IERR;
        }
    }
    else
    {
/*
C VAPOR ROOT DESIRED.  PROCEDURE IS MIRROR IMAGE OF LIQUID PROCEDURE
C IF YOU HAVE FOUND DP > 0, SEARCH TO FIND ROOT
C IF DP < 0, MUST GO DOWN UNTIL A NEGATIVE DP IS FOUND
C AT THAT POINT, TREAT LIKE "NORMAL" CASE AND GO TO SEARCH FOR BOUND
*/        
    	if (DPNEW < 0.0) 
        {
          	DOLD = DD;
          
          	for (int i=1; i<=100; i++)
          	{
            	DNEW = DOLD*0.95;
            	PDP(DNEW, TR, &PNEW, &DPNEW, IWANT, PROPR);
            	DOLD = DNEW;
            	DPOLD = DPNEW;
            
            	if (DPNEW > 0.0) 
            		goto STNO_299;
  			}
        }

        DOLD = DD;
        POLD = PNEW;
        DPOLD = DPNEW;
/*
C IF P TOO LOW, GO UP IN DENSITY UNTIL SOLUTION BOUNDED
*/
STNO_299:
        if (PNEW < P) 
        {
          	for (int i=1; i<=1000; i++)
          	{
            	DINCR = (0.01*(1.0-DOLD) < DOLD*1.1) ? 0.01*(1.0-DOLD) : DOLD*1.1;
            	
            	DNEW = DOLD + DINCR;
            	PDP(DNEW, TR, &PNEW, &DPNEW, IWANT, PROPR);
            
            	if (DPNEW < 0.0) 
            	{
/*
C IF NEGATIVE DPD ENCOUNTERED, SEARCH FOR PLACE WHERE DPD=0.  IF P THERE
C IS STILL TOO LOW, THEN THERE IS NO VAPOR ROOT.  BUT IF YOU GET A 
C POINT WITH DPD>0 AND P TOO HIGH, THE ROOT IS BOUNDED AND YOU CAN SEARCH.
*/
              		FLOW = DPNEW;
              		FHIGH = DPOLD;
              		DLOW = DNEW;
              		DHIGH = DOLD;
              		DPLOW = DPNEW;
              		DPHIGH = DPOLD;
              		PSAV = POLD;
              		DSAV = DOLD;
              		DPSAV = DPOLD;
              
              		for (int j=1; j<=100; j++)
              		{
                		FRDIST = -FLOW / (FHIGH-FLOW);
                		DNEW = DLOW + FRDIST*(DHIGH-DLOW);
                		PDP(DNEW, TR, &PNEW, &DPNEW, IWANT, PROPR);
/*
C CHECK FOR BOUNDING OF DENSITY ROOT
*/
                		if ((DPNEW > 0.0) && (PNEW >= P)) 
                		{
                  			PLOW = PSAV;
                  			DLOW = DSAV;
                  			DPLOW = DPSAV;
                  			PHIGH = PNEW;
                  			DHIGH = DNEW;
                  			DPHIGH = DPNEW;
                  			goto STNO_444;
                		}
/*
C CHECK FOR CONVERGENCE ON DP=0
*/
                		if(fabs(DPNEW) < TOL) 
                		{
                  			*DOUT = DNEW;
                  			*DPD = DPNEW;
                  			IERR = 1;
                  			return IERR;
                		}
/*
C MAKE NEW BOUNDS DEPENDING ON WHETHER NEW GUESS WAS HIGH OR LOW
*/
                		FNEW = DPNEW;
                
                		if (FNEW >= 0.0) 
                		{
                  			FHIGH = FNEW;
                 	 		DHIGH = DNEW;
                  			DPHIGH = DPNEW;
                  		}
                		else
                		{
                  			FLOW = FNEW;
                  			DLOW = DNEW;
                  			DPLOW = DPNEW;
                		}
 					}
            	}

            	if (PNEW >= P) 
            	{
              		PLOW = POLD;
              		DLOW = DOLD;
              		DPLOW = DPOLD;
              		PHIGH = PNEW;
              		DHIGH = DNEW;
              		DPHIGH = DPNEW;
              		goto STNO_444;
            	}
            	
            	DOLD = DNEW;
            	POLD = PNEW;
            	DPOLD = DPNEW;
  			}
/*
C IF YOU STILL HAVEN'T BRACKETED IT, GIVE UP
*/
          	*DOUT = DNEW;
          	*DPD = DPNEW;
          	IERR = 2;
          	return IERR;
        }
        else
        {
/*
C IF P TOO HIGH, GO DOWN IN DENSITY UNTIL SOLUTION BOUNDED
*/
          	for (int i=1; i<=100; i++)
          	{
            	DNEW = DOLD*0.9;
            	PDP(DNEW, TR, &PNEW, &DPNEW, IWANT, PROPR);
            
            	if (PNEW <= P) 
            	{
              		PHIGH = POLD;
              		DHIGH = DOLD;
              		DPHIGH = DPOLD;
              		PLOW = PNEW;
              		DLOW = DNEW;
              		DPLOW = DPNEW;
              		goto STNO_444;
            	}
            	
            	DOLD = DNEW;
            	POLD = PNEW;
            	DPOLD = DPNEW;
  			}
/*
C IF YOU STILL HAVEN'T BRACKETED IT, GIVE UP
*/
          	*DOUT = DNEW;
          	*DPD = DPNEW;
          	IERR = 2;
          	return IERR;
        }
    }
    
STNO_444: 
/*
C SOLUTION IS NOW BRACKETED
C SOLVE BY NEWTON BASED ON DERIVATIVE AT NEAREST END, BUT DON'T
C LET IT CROSS THE BOUNDARY
*/
    FLOW = PLOW - P;
    FHIGH = PHIGH - P;
      
    for (int i=1; i<=200; i++)
    {
        if (fabs(FLOW) < fabs(FHIGH)) 
        {
          	DNEW = DLOW + fabs(FLOW/DPLOW);
          	DBOUND = DLOW + 0.9*(DHIGH-DLOW);
          
          	if (DNEW > DBOUND) 
          		DNEW = DBOUND;
        }
        else
        {
          	DNEW = DHIGH - fabs(FHIGH/DPHIGH);
          	DBOUND = DLOW + 0.1*(DHIGH-DLOW);
          
          	if (DNEW < DBOUND) 
          		DNEW = DBOUND;
        }
        
        PDP(DNEW, TR, &PNEW, &DPNEW, IWANT, PROPR);
/*
C CHECK FOR CONVERGENCE
*/
        TOL2 = (TOL < TOL*DPNEW) ? TOL : TOL*DPNEW;
        TOL2 = (1.0e-11 > TOL2) ? 1.0e-11 : TOL2;
        
        if (fabs(1.0 - PNEW/P) < TOL2) 
        	goto STNO_999;
/*
C MAKE NEW BOUNDS DEPENDING ON WHETHER NEW GUESS WAS HIGH OR LOW
*/
        FNEW = PNEW - P;
        
        if (FNEW >= 0.0) 
        {
          	FHIGH = FNEW;
          	DHIGH = DNEW;
          	DPHIGH = DPNEW;
        }
        else
        {
          	FLOW = FNEW;
          	DLOW = DNEW;
          	DPLOW = DPNEW;
        }
  	}
/*
C FAILURE TO CONVERGE
*/
    *DOUT = DNEW;
    *DPD = DPNEW;
    IERR = 3;
    return IERR;

STNO_999: 
/*
C CONVERGENCE
*/
    IERR = 0;
    *DOUT = DNEW;
    *DPD = DPNEW;
    return IERR;       
}


int PCOEX(double TR, double *PR, double *RHOL, double *RHOV, int IWANT[], double PROPR[])
{
/*
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                     *** PCOEX ***                                    C
C THIS ROUTINE COMPUTES THE REDUCED COEXISTENCE PRESSURE P/PC AT A     C
C GIVEN REDUCED TEMPERATURE TR.  IT ALSO RETURNS THE COEXISTING        C
C DENSITIES.  THE STRATEGY IS TO GET A GOOD INITIAL GUESS AND THEN     C
C CONVERGE THE LN OF THE K-FACTOR TO ZERO.                             C
C                                                                      C
C ARGUMENT LIST:                                                       C
C  NAME  TYPE I/O? EXPLANATION                                         C
C ------ ---- ---- --------------------------------------------------  C
C TR      R    I   REDUCED TEMPERATURE, T/TC                           C
C PR      R    O   REDUCED COEXISTENCE PRESSURE, P/PC                  C
C RHOL    R    O   REDUCED SAT. LIQUID DENSITY, RHOL/RHOC              C
C RHOV    R    O   REDUCED SAT. VAPOR DENSITY, RHOV/RHOC               C
C IWANT   IA   -   PROPERTY REQUEST VECTOR FOR USE IN PROPS2 ROUTINE   C
C PROPR   RA   O   VECTOR OF REDUCED PROPERTIES AS REQUESTED BY IWANT  C
C                  TO BE RETURNED BY THE PROP2 ROUTINE                 C
C IERR    I    O   ERROR FLAG                                          C
C                  0 = SUCCESS                                         C
C                  1 = TEMPERATURE OUT OF RANGE                        C
C                  2 = UNABLE TO BRACKET (PROBABLY BECAUSE VERY CLOSE  C
C                      TO TC) RETURN VALUES FROM SATURATION EQUATIONS  C
C                  3 = UNABLE TO CONVERGE BOUNDED SOLUTION.  RETURN    C
C                      LAST GUESS FOR SOLUTION                         C
C                  4 = TEMPERATURE BELOW TRIPLE POINT BUT IN RANGE     C
C                                                                      C
C MAINTENANCE:                                                         C
C                                                                      C
C 21JUL95 - INITIAL CREATION BY AHH                                    C
C 31AUG95 - HANDLE STEP WHERE CAN'T FIND DENSITY ROOT IN PHASE         C
C 01SEP95 - DON'T TRY TO ITERATE FOR TR > .99999                       C
C 01SEP95 - FORCE AT LEAST A 1% STEP IN BOUNDED SECANT SEARCH          C
C 06SEP95 - USE TR INSTEAD OF TAU IN DFIND ARGUMENT LIST               C
C 06SEP95 - AHH: IMPLEMENT IERR=2 FOR POINTS TOO CLOSE TO TC           C
C 28SEP95 - AHH: PARAMETERIZE NUMBER OF PROPERTIES                     C
C 23MAY96 - AHH: RETURN BETTER NEAR-CRITICAL DENSITIES FOR IERR=2      C
C 30AUG96 - AHH: LOWERCASE INCLUDES FOR OTHER PLATFORMS                C
C 25SEP96 - AHH: SET RHOL AND RHOV FOR IERR=1 TO AVOID UNSET VARS      C
C 09JAN97 - AHH: ALLOW CALCULATIONS BELOW TRIPLE POINT                 C
C 11FEB97 - AHH: MAKE EXP'S UNIFORMLY DOUBLE PRECISION                 C
C 21MAY97 - AHH: USE COMMONS FOR WATER PARAMETERS                      C
C                                                                      C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
*/
	static const double TOL = 1.0e-7;
    static const double TTRIP = TTRIPW/TCW; 
    static const double TMIN = TSMIN/TCW;

	int IERR, IER1, IER2;
	double P0, DP0, RHOL0, RHOV0, DPD, FLIQ, FVAP, XK, F0, POLD, PINCR, PNEW, F1, PLOW, PHIGH; 
	double FLOW, FHIGH, PLNLOW, PLNHI, FRDIST, PLNNEW, FNEW;
/*
C TEMPERATURE RANGE CHECK
*/
    if (TR < TMIN) 
    {
        IERR = 1;
        *PR = 1.0e-8;
        *RHOL = 0.0;
        *RHOV = 0.0;
        return IERR;
    }
    else if (TR >= 1.0) 
    {
        IERR = 1;
        *PR = 1.0;
        *RHOL = 1.0;
        *RHOV = 1.0;
        return IERR;
    }
/*
C GET INITIAL GUESSES FOR PSAT, RHOL, RHOV
*/
    PVAP(TR, &P0, &DP0);

    RHOL0 = DLSAT(TR);
    RHOV0 = DVSAT(TR);
/*
C FIND LIQUID AND VAPOR DENSITIES AT INITIALLY GUESSED PRESSURE
*/
    IER1 = DFIND(RHOL, P0, RHOL0, TR, &DPD, IWANT, PROPR);
    IER2 = DFIND(RHOV, P0, RHOV0, TR, &DPD, IWANT, PROPR);
/*
C IF YOU COULDN'T FIND DENSITY ROOTS AT THE INITIAL GUESS, YOU ARE
C PROBABLY TOO CLOSE TO TC.  RETURN INIT. GUESS VALUES
*/
    if ((IER1 != 0) || (IER2 != 0)) 
    	goto STNO_666;
/*
C GET THE K-FACTOR AT THIS TEMP, RHOL, AND RHOV
*/
    KFACT(TR, *RHOL, *RHOV, &FLIQ, &FVAP, &XK, IWANT, PROPR);
/*
C OBJECTIVE FUNCTION IS NEGATIVE OF LN OF THE K-FACTOR
*/
    F0 = -log(XK);
/*
C NOW SEARCH FOR A PRESSURE ON THE OTHER SIDE OF EQUILIBRIUM
C IF F0 IS NEGATIVE, THE PRESSURE NEEDS TO BE HIGHER
C IF YOU JUMP PAST THE 2-PHASE PART OF THE ISOTHERM, HALVE THE STEP
*/
    POLD = P0;
    
    if (F0 < 0.0) 
    {
        PINCR = .01*(1.0 - P0);
        
        for (int i=1; i<=100; i++)
        {
STNO_110:
			PNEW = POLD + PINCR;  
        	IER1 = DFIND(RHOL, PNEW, RHOL0, TR, &DPD, IWANT, PROPR);
        	IER2 = DFIND(RHOV, PNEW, RHOV0, TR, &DPD, IWANT, PROPR);
          
        	if ((IER1 != 0) || (IER2 != 0)) 
        	{
            	PINCR = 0.5*PINCR;
            	goto STNO_110;
        	}
          
          	KFACT(TR, *RHOL, *RHOV, &FLIQ, &FVAP, &XK, IWANT, PROPR);
          	F1 = -log(XK);
          
          	if (F1 > 0.0) 
          	{
            	PLOW = POLD;
            	PHIGH = PNEW;      
            	FLOW = F0;
            	FHIGH = F1;
            	goto STNO_201;
          	}
          	else
          	{
            	POLD = PNEW;
            	F0 = F1;
          	}
  		}
/*
C - IF YOU GET HERE, YOU WERE UNABLE TO BRACKET THE PRESSURE
*/
        goto STNO_666;
    }
    else
    {
/*
C IF F WAS TOO HIGH, NEED TO LOWER THE PRESSURE
*/
    	PINCR = 0.01*P0;
    
    	for (int i=1; i<=90; i++)
    	{
STNO_210:
			PNEW = POLD - PINCR;
        	IER1 = DFIND(RHOL, PNEW, RHOL0, TR, &DPD, IWANT, PROPR);
        	IER2 = DFIND(RHOV, PNEW, RHOV0, TR, &DPD, IWANT, PROPR);
          
        	if ((IER1 != 0) || (IER2 != 0)) 
        	{
            	PINCR = 0.5*PINCR;
            	goto STNO_210;
        	}
        
        	KFACT(TR, *RHOL, *RHOV, &FLIQ, &FVAP, &XK, IWANT, PROPR);
       	 	F1 = -log(XK);
        
        	if (F1 < 0.0) 
        	{
        		PLOW = PNEW;
            	PHIGH = POLD;     
            	FLOW = F1;
            	FHIGH = F0;
            	goto STNO_201;
        	}
        	else
        	{
            	POLD = PNEW;
            	F0 = F1;
        	}
  		}	  	
/*
C - IF YOU GET HERE, YOU WERE UNABLE TO BRACKET THE PRESSURE
*/
    	goto STNO_666;
    }

STNO_201:
/*
C NOW THE VAPOR PRESSURE IS BRACKETED BY PLOW AND PHIGH, WITH
C CORRESPONDING OBJECTIVE FUNCTION VALUES OF FLOW AND FHIGH.
C CONVERGE ON THE SOLUTION BY SECANT METHOD ON LN P
*/
    PLNLOW = log(PLOW);
    PLNHI  = log(PHIGH);
    
    for (int i=1; i<=100; i++)
    {
        FRDIST = -FLOW / (FHIGH-FLOW);
        
        if (FRDIST < 0.01) 
        	FRDIST = 0.01;
        
        if (FRDIST > 0.99) 
        	FRDIST = 0.99;
        
        PLNNEW = PLNLOW + FRDIST*(PLNHI-PLNLOW);
        PNEW = exp(PLNNEW);        
        IER1 = DFIND(RHOL, PNEW, RHOL0, TR, &DPD, IWANT, PROPR);
        IER2 = DFIND(RHOV, PNEW, RHOV0, TR, &DPD, IWANT, PROPR);
        KFACT(TR, *RHOL, *RHOV, &FLIQ, &FVAP, &XK, IWANT, PROPR);
        FNEW = -log(XK);
/*
C CHECK FOR CONVERGENCE
*/
        if (fabs(FNEW) < TOL) 
        	goto STNO_777;
/*
C MAKE NEW BOUNDS DEPENDING ON WHETHER NEW GUESS WAS HIGH OR LOW
*/
        if (FNEW > 0.0) 
        {
          	FHIGH = FNEW;
          	PHIGH = PNEW;
          	PLNHI = PLNNEW;
        }
        else
        {
          	FLOW = FNEW;
          	PLOW = PNEW;
          	PLNLOW = PLNNEW;
        }
  	}
/*
C IF YOU GET TO HERE, YOU DID NOT CONVERGE ON THE BOUNDED ROOT
*/
    IERR = 3;
    *PR = PNEW;
    return IERR;

STNO_666: 
/*
C GET HERE FOR INITIAL FAILURE OR FAILURE TO BRACKET SOLUTION
C RETURN INITIAL GUESSES
*/
    IERR = 2;
    *PR = P0;
    *RHOL = RHOL0;
    *RHOV = RHOV0;
    
    if (TR > 0.99999) 
    {
        *RHOL = DLSATC(TR);
        *RHOV = DVSATC(TR);
    }
    
    return IERR;

STNO_777:
/*
C CONVERGENCE
*/
    IERR = 0;
/*
C NOTE EXTRAPOLATION BELOW TRIPLE POINT
*/
    if (TR < TTRIP) 
    	IERR = 4;
  
    *PR = PNEW;
    return IERR;
}


int TCOEX(double PR, double *TR, double *RHOL, double *RHOV, int IWANT[], double PROPR[])
{
/*
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                     *** TCOEX ***                                    C
C THIS ROUTINE COMPUTES THE REDUCED COEXISTENCE TEMPERATURE T/TC AT A  C
C GIVEN REDUCED PRESSURE PR.  IT ALSO RETURNS THE COEXISTING           C
C DENSITIES.  THE STRATEGY IS TO GET A GOOD INITIAL GUESS AND THEN     C
C CONVERGE THE LN OF THE K-FACTOR TO ZERO.                             C
C                                                                      C
C ARGUMENT LIST:                                                       C
C  NAME  TYPE I/O? EXPLANATION                                         C
C ------ ---- ---- --------------------------------------------------  C
C PR      R    I   REDUCED PRESSURE, P/PC                              C
C TR      R    O   REDUCED COEXISTENCE TEMPERATURE, T/TC               C
C RHOL    R    O   REDUCED SAT. LIQUID DENSITY, RHOL/RHOC              C
C RHOV    R    O   REDUCED SAT. VAPOR DENSITY, RHOV/RHOC               C
C IWANT   IA   -   PROPERTY REQUEST VECTOR FOR USE IN PROPS2 ROUTINE   C
C PROPR   RA   O   VECTOR OF REDUCED PROPERTIES AS REQUESTED BY IWANT  C
C                  TO BE RETURNED BY THE PROP2 ROUTINE                 C
C IERR    I    O   ERROR FLAG                                          C
C                  0 = SUCCESS                                         C
C                  1 = TEMPERATURE OUT OF RANGE                        C
C                  2 = UNABLE TO BRACKET (PROBABLY BECAUSE VERY CLOSE  C
C                      TO TC) RETURN VALUES FROM SATURATION EQUATIONS  C
C                  3 = UNABLE TO CONVERGE BOUNDED SOLUTION.  RETURN    C
C                      LAST GUESS FOR SOLUTION                         C
C                  4 = TEMPERATURE BELOW TRIPLE POINT BUT IN RANGE     C
C                                                                      C
C MAINTENANCE:                                                         C
C                                                                      C
C 06SEP95 - INITIAL CREATION BY AHH (FROM PCOEX)                       C   
C 28SEP95 - AHH: PARAMETERIZE NUMBER OF PROPERTIES                     C
C 23MAY96 - AHH: RETURN BETTER NEAR-CRITICAL DENSITIES FOR IERR=2      C
C 30AUG96 - AHH: LOWERCASE INCLUDES FOR OTHER PLATFORMS                C
C 25SEP96 - AHH: SET RHOL AND RHOV FOR IERR=1 TO AVOID UNSET VARS      C
C 09JAN97 - AHH: ALLOW CALCULATIONS BELOW TRIPLE POINT                 C
C 21MAY97 - AHH: USE COMMONS FOR WATER PARAMETERS                      C
C                                                                      C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
*/
    static const double TOL = 1.0e-8; 
    static const double TOL2 = 1.0e-7;
    static const double PTRIP = PTRIPW/PCW; 
    static const double PMIN = PSMIN/PCW;
 
	int IERR, IER1, IER2;
	double RHOL0, RHOV0, T0, DPD, FLIQ, FVAP, XK, F0, TOLD, TINCR, F1, TNEW;
	double TAULOW, TLOW, TAUHI, THIGH, FRDIST, FLOW, FHIGH, TAUNEW, FNEW;
	
 /* PRESSURE RANGE CHECK   */
    if (PR < PMIN) 
    {
        IERR = 1;
        *TR = 1.0e-8;
        *RHOL = 0.0;
        *RHOV = 0.0;
        return IERR;
    }
    else if (PR >= 1.0) 
    {
        IERR = 1;
        *TR = 1.0;
        *RHOL = 1.0;
        *RHOV = 1.0;
        return IERR;
    }
/*
C GET INITIAL GUESSES FOR PSAT, RHOL, RHOV
*/
    T0 = TVAP(PR);      
    RHOL0 = DLSAT(T0);
    RHOV0 = DVSAT(T0);
/*
C FIND LIQUID AND VAPOR DENSITIES AT INITIALLY GUESSED TEMPERATURE
*/
    IER1 = DFIND(RHOL, PR, RHOL0, T0, &DPD, IWANT, PROPR);
    IER2 = DFIND(RHOV, PR, RHOV0, T0, &DPD, IWANT, PROPR);
/*
C IF YOU COULDN'T FIND DENSITY ROOTS AT THE INITIAL GUESS, YOU ARE
C PROBABLY TOO CLOSE TO TC.  RETURN INIT. GUESS VALUES
*/
    if ((IER1 != 0) || (IER2 != 0)) 
    	goto STNO_666;
/*
C GET THE K-FACTOR AT THIS TEMP, RHOL, AND RHOV
*/
    KFACT(T0, *RHOL, *RHOV, &FLIQ, &FVAP, &XK, IWANT, PROPR);
/*
C OBJECTIVE FUNCTION IS LN OF THE K-FACTOR
*/
    F0 = log(XK);
/*
C NOW SEARCH FOR A TEMPERATURE ON THE OTHER SIDE OF EQUILIBRIUM
C IF F0 IS NEGATIVE, THE TEMPERATURE NEEDS TO BE HIGHER
C IF YOU JUMP PAST THE 2-PHASE PART OF THE ISOTHERM, HALVE THE STEP
*/
    TOLD = T0;
      
    if (F0 < 0.0) 
    {
        TINCR = .01*(1.0 - T0);
        
        for (int i=1; i<=100; i++)
        {
STNO_110:
			TNEW = TOLD + TINCR;
          	IER1 = DFIND(RHOL, PR, RHOL0, TNEW, &DPD, IWANT, PROPR);
          	IER2 = DFIND(RHOV, PR, RHOV0, TNEW, &DPD, IWANT, PROPR);
          
          	if ((IER1 != 0) || (IER2 != 0)) 
          	{
            	TINCR = 0.5*TINCR;
            	goto STNO_110;
          	}
          
          	KFACT(TNEW, *RHOL, *RHOV, &FLIQ, &FVAP, &XK, IWANT, PROPR);
          	F1 = log(XK);
          
          	if (F1 > 0.0) 
          	{
            	TLOW = TOLD;
            	THIGH = TNEW;      
            	FLOW = F0;
            	FHIGH = F1;
            	goto STNO_201;
          	}
          	else
          	{
            	TOLD = TNEW;
            	F0 = F1;
          	}
  		}
/*
C - IF YOU GET HERE, YOU WERE UNABLE TO BRACKET THE TEMPERATURE
*/
        goto STNO_666;

    }
    else
    {
/*
C IF F WAS TOO HIGH, NEED TO LOWER THE TEMPERATURE
*/
        TINCR = .01*T0;
        
        for (int i=1; i<=90; i++)
        {
STNO_210:     
			TNEW = TOLD - TINCR;
          	IER1 = DFIND(RHOL, PR, RHOL0, TNEW, &DPD, IWANT, PROPR);
          	IER2 = DFIND(RHOV, PR, RHOV0, TNEW, &DPD, IWANT, PROPR);
          
          	if ((IER1 != 0) || (IER2 != 0)) 
          	{
            	TINCR = 0.5*TINCR;
            	goto STNO_210;
          	}
          	
        	KFACT(TNEW, *RHOL, *RHOV, &FLIQ, &FVAP, &XK, IWANT, PROPR);
          	F1 = log(XK);
          
          	if (F1 < 0.0) 
          	{
            	TLOW = TNEW;
            	THIGH = TOLD;     
            	FLOW = F1;
            	FHIGH = F0;
            	goto STNO_201;
          	}
          	else
          	{
            	TOLD = TNEW;
            	F0 = F1;
          	}
  		}
/*
C - IF YOU GET HERE, YOU WERE UNABLE TO BRACKET THE TEMPERATURE
*/
        goto STNO_666;
    }

STNO_201: 
/*
C NOW THE SATURATION TEMPERATURE IS BRACKETED BY TLOW AND THIGH, WITH
C CORRESPONDING OBJECTIVE FUNCTION VALUES OF FLOW AND FHIGH.
C CONVERGE ON THE SOLUTION BY SECANT METHOD ON 1/TR
*/
    TAULOW = 1.0/TLOW;
    TAUHI  = 1.0/THIGH;
      
    for (int i=1; i<=100; i++)
    {
    	FRDIST = -FLOW / (FHIGH-FLOW);
        
        if (FRDIST < 0.01) FRDIST = 0.01;
        
        if (FRDIST > 0.99) FRDIST = 0.99;
        
        TAUNEW = TAULOW + FRDIST*(TAUHI-TAULOW);
        TNEW = 1.0/TAUNEW;
        IER1 = DFIND(RHOL, PR, RHOL0, TNEW, &DPD, IWANT, PROPR);
        IER2 = DFIND(RHOV, PR, RHOV0, TNEW, &DPD, IWANT, PROPR);
        KFACT(TNEW, *RHOL, *RHOV, &FLIQ, &FVAP, &XK, IWANT, PROPR);
        FNEW = log(XK);
/*
C CHECK FOR CONVERGENCE
*/
        if (fabs(FNEW) < TOL) goto STNO_777;
        
        if ((PR < PTRIP) && (fabs(FNEW) < TOL2)) goto STNO_777;
/*
C MAKE NEW BOUNDS DEPENDING ON WHETHER NEW GUESS WAS HIGH OR LOW
*/
        if (FNEW > 0.0) 
        {
          	FHIGH = FNEW;
          	THIGH = TNEW;
          	TAUHI = TAUNEW;
        }
        else
        {
          	FLOW = FNEW;
          	TLOW = TNEW;
          	TAULOW = TAUNEW;
        }
  	}
/*
C IF YOU GET TO HERE, YOU DID NOT CONVERGE ON THE BOUNDED ROOT
*/
    IERR = 3;
    *TR = TNEW;
    return IERR;

STNO_666: 
/*
C GET HERE FOR INITIAL FAILURE OR FAILURE TO BRACKET SOLUTION
C RETURN INITIAL GUESSES
*/
    IERR = 2;
    *TR = T0;
    *RHOL = RHOL0;
    *RHOV = RHOV0;
      
    if (*TR > 0.99999) 
    {
        *RHOL = DLSATC(*TR);
        *RHOV = DVSATC(*TR);
    }
    
    return IERR;

STNO_777:
/*
C CONVERGENCE
*/
    IERR = 0;
/*
C NOTE EXTRAPOLATION BELOW TRIPLE POINT
*/
    if (PR < PTRIP) IERR = 4;
  
    *TR = TNEW;
      
    return IERR;
}

/*
	PHSOLV, PSSOLV & TSSOLV are only called by HSSOLV in INTPK.  However, HSSOLV is not 
	called and so has been deleted.  Thus, PHSOLV, PSSOLV & TSSOLV were also deleted.
	
      SUBROUTINE PHSOLV(PR, HTR, TR, TMAX, TMIN, TRECMX, TRECMN, D1R,
     >                  DVR, DLR, I2PH, Q, IWANT, PROPR, IERR)

      SUBROUTINE PSSOLV(PR, SR, TR, TMAX, TMIN, TRECMX, TRECMN, D1R,
     >                  DVR, DLR, I2PH, Q, IWANT, PROPR, IERR)

      SUBROUTINE TSSOLV(PR, SR, TR, PMAX, PMIN, PRECMX, PRECMN, D1R,
     >                  DVR, DLR, I2PH, Q, IWANT, PROPR, IERR)
*/
